@@ -1,3 +1,8 @@
+"""
+Exceptions that could be raised during one of the git commands
+"""
+
+
 class GitException(Exception):
     pass
 
@@ -20,3 +25,7 @@ class NoLogsException(GitException):
 
 class UnknownRevisionException(GitException):
     pass
+
+
+class UnknownRefException(GitException):
+    pass
